@@ -19,6 +19,7 @@ from __future__ import annotations
 
 import warnings
 
+from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.providers.common.sql.operators.sql import SQLCheckOperator
 
 
@@ -28,11 +29,11 @@ class DruidCheckOperator(SQLCheckOperator):
     Please use `airflow.providers.common.sql.operators.sql.SQLCheckOperator`.
     """
 
-    def __init__(self, druid_broker_conn_id: str = 'druid_broker_default', **kwargs):
+    def __init__(self, druid_broker_conn_id: str = "druid_broker_default", **kwargs):
         warnings.warn(
             """This class is deprecated.
             Please use `airflow.providers.common.sql.operators.sql.SQLCheckOperator`.""",
-            DeprecationWarning,
+            AirflowProviderDeprecationWarning,
             stacklevel=2,
         )
         super().__init__(conn_id=druid_broker_conn_id, **kwargs)
